# L1-IFS Data model
## 单次曝光处理_File：CSST_IFS_type_yyyymmddHHMMSS_yyyymmddHHMMSS_obsid_camera_L1_VER_process.fits
### File name description
type:&nbsp;    目标类型，4位字符串,对于科学数据为‘SCIE’\
yyyymmdd:&nbsp;八位数观测日期，如20240101\
HHMMSS:&nbsp;  六位数UT观测时间，如122838\
两组时间为起始曝光时间和结束曝光时间\
obsid:&nbsp;   CSST统一的曝光编号，从相应0级数据继承\
camera:&nbsp;  光谱仪编号,1位字符串,红端为“R”,蓝端为“B”,红蓝拼接后的全谱为“A”\
L1:&nbsp;      表示文件为1级科学观测数据\
VER:&nbsp;     版本号，1位字符串和4位数字的组合,如R4203是DRP中RSS处理模块 v4.2.03 版本\
process:&nbsp; 8位字符串,代表8步基本数据处理流程，由字母表示,含义如下:
```
e：已抽谱
w：已进行波长定标
n：已对平场归一
r：已扣除宇宙线
f：已进行流量定标
c：已生成三维数据块
g: 已完成天体测量位置（IFS-WCS）定标
```
### File contents
| HDU  | data                    | note       |
|------|-------------------------|------------|
| HDU0 | None                    | PrimaryHDU |
| HDU1 | FLUX                    | ImageHDU   |
| HDU2 | IVAR                    | ImageHDU   |
| HDU3 | MASK                    | ImageHDU   |

### HDU0
#### Header of `csst_ifs_rss`
| Level 1 extension header keywords (new) |                                                                     |        |                                                                                                          |
|-----------------------------------------|---------------------------------------------------------------------|--------|----------------------------------------------------------------------------------------------------------|
| Keyword                                 | Description                                                         | Format | Remark                                                                                                   |
| Standard keywords                       |                                                                     |        |                                                                                                          |
| XTENSION                                | IMAGE extension                                                     | C8     | 'IMAGE   '                                                                                               |
| BITPIX                                  | Number of bits per data pixel                                       | I4     | -32                                                                                                      |
| NAXIS                                   | Number of data axes                                                 | I4     | 3                                                                                                        |
| NAXIS1                                  | Number of spatial bins in X axis                                    | I4     | 32                                                                                                       |
| NAXIS2                                  | Number of spatial bins in Y axis                                    | I4     | 32                                                                                                       |
| NAXIS3                                  | Number of wavelength bins                                           | I4     | NWAVE                                                                                                    |
| Image processing keywords               |                                                                     |        |                                                                                                          |
| PROCESS                                 | RSS process record                                                  | C8     | ‘bewnrfcg’                                                                                               |
| RSS_VER                                 | version of RSS code                                                 | C5     |                                                                                                          |
| FLUXUNIT                                | Flux unit                                                           | C20    | 1E-17 erg/s/cm2/Å/arcsec2                                                                                |
| HISTORY                                 | Time of last image processing                                       | C80    |                                                                                                          |
| BIAS_MAS                                |  The file name of the master bias.                                  | C80    |                                                                                                          |
| DARK_MAS                                |  The file name of the master dark                                   | C80    |                                                                                                          |
| FLAT_MAS                                | The file name of the master flat                                    | C80    |                                                                                                          |
| LAMP_MAS                                |  The file name of the master lamp                                   | C80    |                                                                                                          |
| TRACFILE                                |  The reference file of trace                                        | C80    |                                                                                                          |
| PTOWFILE                                |  The reference file of pixel-to-wavelength solution                 | C80    |                                                                                                          |
| STDSTAR                                 |  The filename of the stardard star.                                 | C80    |                                                                                                          |
| HASCTE                                  | Has CTE correction                                                  | C01    | T or F                                                                                                   |
| HASSAT                                  | Has satellite correction                                            | C01    | T or F                                                                                                   |
| HASSCA                                  | Has stray light correction                                          | C01    | T or F                                                                                                   |
| QCFLUX                                  | The counts of NAN+INF in flux                                       | I4     |                                                                                                          |
| QCIV                                    | The counts of NAN+INF in IV                                         | I4     |                                                                                                          |
|                                         |                                                                     |        |                                                                                                          |
| IFS-WCS Calibration keywords            |                                                                     |        |                                                                                                          |
| WCSCAL_S                                | Determination of WCS calibration completion                         | I4     | The completion status is determined according to different situations, 0 means no operation is performed |
| WCSCAL_V                                | Version of WCS calibration                                          | Cxx    |                                                                                                          |
| WCSCAL_P                                | Name of the  configuration file used for WCS calibration            | Cxx    |                                                                                                          |
| WCS_TLM                                 | Time of last wcs calibration                                        | Cxx    | Time of the last WCS calibration                                                                         |
| RADECSYS                                | Frame of reference of coordinates                                   | C08    | 'ICRS' or 'FK5'                                                                                          |
| EQUINOX                                 |                                                                     | R4     | always 2000.0                                                                                            |
| CD1_1                                   | Coordinate transformation matrix element                            | R8     |                                                                                                          |
| CD1_2                                   | Coordinate transformation matrix element                            | R8     |                                                                                                          |
| CD2_1                                   | Coordinate transformation matrix element                            | R8     |                                                                                                          |
| CD2_2                                   | Coordinate transformation matrix element                            | R8     |                                                                                                          |
| CTYPE1                                  | Right Ascension, gnomonic projection                                | C8     | 'RA---TAN'                                                                                               |
| CTYPE2                                  | Declination, gnomonic projection                                    | C8     | 'DEC--TAN'                                                                                               |
| CUNIT1                                  | Units of coordinate increment and value                             | C4     | 'DEG'                                                                                                    |
| CUNIT2                                  | Units of coordinate increment and value                             | C4     | 'DEG'                                                                                                    |
| CRPIX1                                  | Pixel coordinate of reference point                                 | R8     |                                                                                                          |
| CRPIX2                                  | Pixel coordinate of reference point                                 | R8     |                                                                                                          |
| CRVAL1                                  | RA of reference point                                               | R8     | deg                                                                                                      |
| CRVAL2                                  | DEC of reference point                                              | R8     | deg                                                                                                      |
| CSYER1                                  | Systematic error in coordinate                                      | R8     | deg                                                                                                      |
| CSYER2                                  | Systematic error in coordinate                                      | R8     | deg                                                                                                      |
| CTYPE3                                  | The type of wavelength array                                        | C8     | 'WAVE-LIN' or 'WAVE-LOG'                                                                                 |
| CUNIT3                                  | unit of wavelength array                                            | C8     | Angstrom                                                                                                 |
| CRPIX3                                  | Starting pixel                                                      | R8     |                                                                                                          |
| CRVAL3                                  | The central wavelength wv0 of first pixel                           | R8     | Angstrom                                                                                                 |
| CD3_3                                   | wavelength dispersion per pixel                                     | R8     | Angstrom                                                                                                 |
| GGUIFILE                                | Geometric data object file of the guider camera relative to the IFS | Cxx    |                                                                                                          |
| IGUIFILE                                | Image data object file for guider accompanying observations         | Cxx    |                                                                                                          |
| GMCIFILE                                | Geometric data object file of the MCI relative to the IFS           | Cxx    |                                                                                                          |
| IMCIFILE                                | Image data object file for MCI accompanying observations            | Cxx    |

## 多次曝光叠加_File: CSST_IFS_CUBE_{OBJ_id}_{VER_cube}_{LIN/LOG}_{STM_cube}.fits

### File contents

| HDU  | data                    | note       |
|------|-------------------------|------------|
| HDU0 | None                    | PrimaryHDU |
| HDU1 | FLUX                    | ImageHDU   |
| HDU2 | IVAR                    | ImageHDU   |
| HDU3 | MASK                    | ImageHDU   |
| HDU4 | EXP_NUM                 | ImageHDU   |
| HDU5 | LSF                     | ImageHDU   |
| HDU6 | WEIGHT_MARTIX           | ImageHDU   |
| HDU7 | rRSS_FILE_LIST          | BinTableHDU|

### HDU0

#### Header of `csst_ifs_cube`

| keyword   | value                 | comment                                           | fill value   | type | module                   |
|-----------|:----------------------|---------------------------------------------------|--------------|------|--------------------------|
| RSS_VER   | R6100                 | version of RSS code                               | RXXXX        |str   | csst_ifs_cube            |
| CUB_VER   | C6100                 | version of CUBE code                              | CXXXX        |str   | csst_ifs_cube            |
| COV_VER   | C6100                 | version of CUBE code                              | CXXXX        |str   | csst_ifs_cube            |
| LSF_VER   | C6100                 | version of CUBE code                              | CXXXX        |str   | csst_ifs_cube            |
| FLUXUNIT  | '1E-17 erg/s/cm2/A/arcsec2' | unit of flux                                | '1E-17 erg/s/cm2/A/arcsec2'|str   | csst_ifs_cube |
| FLUXSCALE | 1                     | Intensity unit scaling                            | 1            |I8    | csst_ifs_cube            |
| FLUXZERO  | 0                     | Intensity zeropoint                               | 0            |I8    | csst_ifs_cube            |
|TELESCOP	| CSST                  | Telescope used to acquire data		            | CSST         |str   | csst_ifs_cube            |
|INSTRUMENT	| IFS                   | Identifier for instrument used to acquire data    | IFS          |str   | csst_ifs_cube            |
|OBJID      | 174053.8-534326'      | ID of Object(in the form of HHMMSS.S+DDMMSS)      | hhmmss.sddmmss|str  | csst_ifs_cube            |
|NEXP       | 50                    | number of science exposures combined              | 0            |I8    | csst_ifs_cube            |
|EXPTIME    | 60000                 | Total exposure time                               | 0            |f32   | csst_ifs_cube            |
|MJDMIN     | 2459955.2275463       | Minimum OBS MJD across all exposures              | -9999        |f32   | csst_ifs_cube            |
|MJDMAX     | 2459955.39282407      | Maximum OBS MJD across all exposures              | -9999        |f32   | csst_ifs_cube            |
|MJDMED     | 2459955.34074074      | Median OBS MJD across all exposures               | -9999        |f32   | csst_ifs_cube            |
|WCSCAL_VER | A6101                 | Version of WCS calibration	                    | AXXX         |str   | csst_ifs_cube            |
|WCSCAL_P	|                       | file for WCS calibration 	                        |  "?"         |str   | csst_ifs_cube            |
|RADECSYS	| FK5                   | Frame of reference of coordinates                 | FK5          |str   | csst_ifs_cube            |
|EQUINOX    | 2000.0                |                                                   | 2000.0       |str   | csst_ifs_cube            |
|OBJRA	    | 265.22407917          | Object R.A. (J2000 deg.)                          | -9999        |f32   | csst_ifs_cube            |
|OBJDEC     | -53.72406389          | Object Dec. (J2000 deg.)                          | -9999        |f32   | csst_ifs_cube            |
|CENRA	    | 265.2240087483441     | Plate center R.A. (J2000 deg.)	R4	            | -9999        |f32   | csst_ifs_cube            |
|CENDEC	    | -53.72410555664603    | Plate center Dec. (J2000 deg.)	R4	            | -9999        |f32   | csst_ifs_cube            |
|CTYPE3	    | 'LIN'                 | The type of wavelength array                      | 'LIN'        |str   | csst_ifs_cube            |
|CRPIX3	    | 1.0                   | Starting pixel	                                | -9999        |f32   | csst_ifs_cube            |
|CRVAL3	    | 3500.0                | The central wavelength wv0 of first pixel 	    | -9999        |f32   | csst_ifs_cube            |
|CD3_3	    | 1.75                  | wavelength dispersion per pixel	                | -9999        |f32   | csst_ifs_cube            |
|CUNIT3	    | 'Angstrom'            | unit of wavelength                                | 'Angstrom'   |str   | csst_ifs_cube            |
|CRPIX1	    | 49.0                  | Reference pixel	                                | -9999        |f32   | csst_ifs_cube            |
|CRPIX2	    | 52.0                  | Reference pixel	                                | -9999        |f32   | csst_ifs_cube            |
|CRVAL1	    | 265.22407917          | RA of reference point	                            | -9999        |f32   | csst_ifs_cube            |
|CRVAL2     | -53.72406389	        | Dec of reference point	                        | -9999        |f32   | csst_ifs_cube            |
|CD1_1	    | -2.7777777777777E-05  | Coordinate transformation matrix element	        | -9999        |f32   | csst_ifs_cube            |
|CD1_2	    | 0.0                   | Coordinate transformation matrix element	        | -9999        |f32   | csst_ifs_cube            |
|CD2_1	    | 0.0                   | Coordinate transformation matrix element	        | -9999        |f32   | csst_ifs_cube            |
|CD2_2	    | 2.7777777777778E-05   | Coordinate transformation matrix element	        | -9999        |f32   | csst_ifs_cube            |
|CTYPE1     | 'RA---TAN'	        | Declination, gnomonic projection	                | 'RA---TAN'   |str   | csst_ifs_cube            |
|CTYPE2     | 'DEC--TAN'	        | Declination, gnomonic projection	                | 'DEC--TAN'   |str   | csst_ifs_cube            |
|CUNIT1	    | 'deg'                 | Units of coordinate increment and value	        | 'deg'        |str   | csst_ifs_cube            |
|CUNIT2	    | 'deg'                 | Units of coordinate increment and value	        | 'deg'        |str   | csst_ifs_cube            |
|EBVGAL     | 0	                    | Galactic reddening E(B-V)	                        | -9999        |f32   | csst_ifs_cube            |
|CHECKSUM   | 0                     |checksum                                           | 1            |I8    | csst_ifs_cube            |
